instancelib.machinelearning package
===================================

Submodules
----------

.. toctree::
   :maxdepth: 4

   instancelib.machinelearning.base
   instancelib.machinelearning.featurematrix
   instancelib.machinelearning.skdata
   instancelib.machinelearning.sklearn
   instancelib.machinelearning.skvectors

Module contents
---------------

.. automodule:: instancelib.machinelearning
   :members:
   :undoc-members:
   :show-inheritance:
